@@ -42,9 +42,6 @@ struct _GoaDaemon
 
   GoaManager *manager;
 
-  GQueue *ensure_credentials_queue;
-  gboolean ensure_credentials_running;
-
   guint config_timeout_id;
   guint credentials_timeout_id;
 };
@@ -77,8 +74,6 @@ static gboolean on_account_handle_ensure_credentials (GoaAccount            *acc
                                                       GDBusMethodInvocation *invocation,
                                                       gpointer               user_data);
 
-static void ensure_credentials_queue_check (GoaDaemon *self);
-
 static void goa_daemon_check_credentials (GoaDaemon *self);
 static void goa_daemon_reload_configuration (GoaDaemon *self);
 
@@ -118,7 +113,6 @@ goa_daemon_finalize (GObject *object)
   g_object_unref (self->manager);
   g_object_unref (self->object_manager);
   g_object_unref (self->connection);
-  g_queue_free_full (self->ensure_credentials_queue, g_object_unref);
 
   G_OBJECT_CLASS (goa_daemon_parent_class)->finalize (object);
 }
@@ -183,7 +177,7 @@ on_check_credentials_timeout (gpointer user_data)
   GoaDaemon *self = GOA_DAEMON (user_data);
 
   self->credentials_timeout_id = 0;
-  g_debug ("Calling EnsureCredentials due to network changes");
+  g_debug ("Checking credentials");
   goa_daemon_check_credentials (self);
 
   return G_SOURCE_REMOVE;
@@ -281,8 +275,6 @@ goa_daemon_init (GoaDaemon *self)
                            self,
                            G_CONNECT_SWAPPED);
 
-  self->ensure_credentials_queue = g_queue_new ();
-
   /* Export objects */
   g_dbus_object_manager_server_set_connection (self->object_manager, self->connection);
 
@@ -486,7 +478,6 @@ update_account_object (GoaDaemon           *self,
   GoaAccount *account;
   GoaProvider *provider;
   gboolean is_locked;
-  gboolean is_temporary;
   gboolean ret;
   gchar *identity;
   gchar *presentation_identity;
@@ -517,7 +508,6 @@ update_account_object (GoaDaemon           *self,
   identity = g_key_file_get_string (key_file, group, "Identity", NULL);
   presentation_identity = g_key_file_get_string (key_file, group, "PresentationIdentity", NULL);
   is_locked = g_key_file_get_boolean (key_file, group, "IsLocked", NULL);
-  is_temporary = g_key_file_get_boolean (key_file, group, "IsTemporary", NULL);
   if (just_added)
     {
       account = goa_account_skeleton_new ();
@@ -540,7 +530,6 @@ update_account_object (GoaDaemon           *self,
   goa_account_set_identity (account, identity);
   goa_account_set_presentation_identity (account, presentation_identity);
   goa_account_set_is_locked (account, is_locked);
-  goa_account_set_is_temporary (account, is_temporary);
 
   error = NULL;
   if (!goa_provider_build_object (provider, object, key_file, group, self->connection, just_added, &error))
@@ -910,8 +899,23 @@ get_all_providers_cb (GObject      *source,
       g_key_file_set_string (key_file, group, key, value);
     }
 
+  g_free (key_file_data);
   error = NULL;
-  if (!g_key_file_save_to_file (key_file, path, &error))
+  key_file_data = g_key_file_to_data (key_file,
+                                      &length,
+                                      &error);
+  if (key_file_data == NULL)
+    {
+      g_prefix_error (&error, "Error generating key-value-file: ");
+      g_dbus_method_invocation_take_error (data->invocation, error);
+      goto out;
+    }
+
+  error = NULL;
+  if (!g_file_set_contents (path,
+                            key_file_data,
+                            length,
+                            &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_dbus_method_invocation_take_error (data->invocation, error);
@@ -939,7 +943,9 @@ get_all_providers_cb (GObject      *source,
   g_free (group);
   g_free (id);
   g_free (path);
-  g_clear_pointer (&key_file, (GDestroyNotify) g_key_file_free);
+  if (key_file != NULL)
+    g_key_file_free (key_file);
+
   g_object_unref (data->daemon);
   g_object_unref (data->manager);
   g_object_unref (data->invocation);
@@ -992,6 +998,8 @@ on_account_handle_remove (GoaAccount            *account,
   const gchar *provider_type;
   gchar *path;
   gchar *group;
+  gchar *data;
+  gsize length;
   GError *error;
 
   provider = NULL;
@@ -999,6 +1007,7 @@ on_account_handle_remove (GoaAccount            *account,
   path = NULL;
   group = NULL;
   key_file = NULL;
+  data = NULL;
 
   if (goa_account_get_is_locked (account))
     {
@@ -1038,7 +1047,21 @@ on_account_handle_remove (GoaAccount            *account,
     }
 
   error = NULL;
-  if (!g_key_file_save_to_file (key_file, path, &error))
+  data = g_key_file_to_data (key_file,
+                             &length,
+                             &error);
+  if (data == NULL)
+    {
+      g_prefix_error (&error, "Error generating key-value-file: ");
+      g_dbus_method_invocation_take_error (invocation, error);
+      goto out;
+    }
+
+  error = NULL;
+  if (!g_file_set_contents (path,
+                            data,
+                            length,
+                            &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_dbus_method_invocation_take_error (invocation, error);
@@ -1083,7 +1106,9 @@ on_account_handle_remove (GoaAccount            *account,
 
  out:
   g_clear_object (&provider);
-  g_clear_pointer (&key_file, (GDestroyNotify) g_key_file_free);
+  g_free (data);
+  if (key_file != NULL)
+    g_key_file_free (key_file);
   g_free (group);
   g_free (path);
   return TRUE; /* invocation was handled */
@@ -1093,25 +1118,28 @@ on_account_handle_remove (GoaAccount            *account,
 
 typedef struct
 {
+  GoaDaemon *daemon;
   GoaObject *object;
-  GList *invocations;
+  GDBusMethodInvocation *invocation;
 } EnsureData;
 
 static EnsureData *
-ensure_data_new (GoaObject             *object,
-                 GDBusMethodInvocation *invocation)
+ensure_data_new (GoaDaemon             *self,
+                             GoaObject             *object,
+                             GDBusMethodInvocation *invocation)
 {
   EnsureData *data;
   data = g_slice_new0 (EnsureData);
+  data->daemon = g_object_ref (self);
   data->object = g_object_ref (object);
-  data->invocations = g_list_prepend (data->invocations, invocation);
+  data->invocation = invocation;
   return data;
 }
 
 static void
 ensure_data_unref (EnsureData *data)
 {
-  g_list_free (data->invocations);
+  g_object_unref (data->daemon);
   g_object_unref (data->object);
   g_slice_free (EnsureData, data);
 }
@@ -1138,48 +1166,13 @@ is_authorization_error (GError *error)
 }
 
 static void
-ensure_credentials_queue_complete (GList *invocations, GoaAccount *account, gint expires_in, GError *error)
+ensure_credentials_cb (GoaProvider   *provider,
+                       GAsyncResult  *res,
+                       gpointer       user_data)
 {
-  GList *l;
-  const gchar *id;
-  const gchar *provider_type;
-  gint64 timestamp;
-
-  for (l = invocations; l != NULL; l = l->next)
-    {
-      GDBusMethodInvocation *invocation = G_DBUS_METHOD_INVOCATION (l->data);
-
-      if (invocation == NULL)
-        continue;
-
-      if (error == NULL)
-        goa_account_complete_ensure_credentials (account, invocation, expires_in);
-      else
-        g_dbus_method_invocation_return_gerror (invocation, error);
-    }
-
-  id = goa_account_get_id (account);
-  provider_type = goa_account_get_provider_type (account);
-  timestamp = g_get_monotonic_time ();
-  g_debug ("%" G_GINT64_FORMAT ": Handled EnsureCredentials (%s, %s)", timestamp, provider_type, id);
-}
-
-static void
-ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, gpointer user_data)
-{
-  GTask *task = G_TASK (user_data);
-  GoaDaemon *self;
-  EnsureData *data;
-  GoaAccount *account;
-  GoaProvider *provider = GOA_PROVIDER (source_object);
-  GError *error;
+  EnsureData *data = user_data;
   gint expires_in;
-
-  self = GOA_DAEMON (g_task_get_source_object (task));
-  g_assert (task == G_TASK (g_queue_pop_head (self->ensure_credentials_queue)));
-
-  data = g_task_get_task_data (task);
-  account = goa_object_peek_account (data->object);
+  GError *error;
 
   error= NULL;
   if (!goa_provider_ensure_credentials_finish (provider, &expires_in, res, &error))
@@ -1187,6 +1180,8 @@ ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, g
       /* Set AttentionNeeded only if the error is an authorization error */
       if (is_authorization_error (error))
         {
+          GoaAccount *account;
+          account = goa_object_peek_account (data->object);
           if (!goa_account_get_attention_needed (account))
             {
               goa_account_set_attention_needed (account, TRUE);
@@ -1197,11 +1192,19 @@ ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, g
             }
         }
 
-      ensure_credentials_queue_complete (data->invocations, account, 0, error);
-      g_error_free (error);
+      if (data->invocation != NULL)
+        {
+          g_dbus_method_invocation_take_error (data->invocation, error);
+          error = NULL;
+        }
+
+      g_clear_error (&error);
     }
   else
     {
+      GoaAccount *account;
+      account = goa_object_peek_account (data->object);
+
       /* Clear AttentionNeeded flag if set */
       if (goa_account_get_attention_needed (account))
         {
@@ -1211,111 +1214,10 @@ ensure_credentials_queue_collector (GObject *source_object, GAsyncResult *res, g
                      g_dbus_object_get_object_path (G_DBUS_OBJECT (data->object)));
         }
 
-      ensure_credentials_queue_complete (data->invocations, account, expires_in, NULL);
+      if (data->invocation != NULL)
+        goa_account_complete_ensure_credentials (account, data->invocation, expires_in);
     }
-
-  self->ensure_credentials_running = FALSE;
-  ensure_credentials_queue_check (self);
-  g_object_unref (task);
-}
-
-static gint
-ensure_credentials_queue_sort (gconstpointer a, gconstpointer b, gpointer user_data)
-{
-  GTask *task_a = G_TASK (a);
-  GTask *task_b = G_TASK (b);
-  gint priority_a;
-  gint priority_b;
-
-  priority_a = g_task_get_priority (task_a);
-  priority_b = g_task_get_priority (task_b);
-
-  return priority_a - priority_b;
-}
-
-static void
-ensure_credentials_queue_check (GoaDaemon *self)
-{
-  EnsureData *data;
-  GoaAccount *account;
-  GoaProvider *provider = NULL;
-  GTask *task;
-  const gchar *id;
-  const gchar *provider_type;
-  gint64 timestamp;
-
-  if (self->ensure_credentials_running)
-    goto out;
-
-  if (self->ensure_credentials_queue->length == 0)
-    goto out;
-
-  g_queue_sort (self->ensure_credentials_queue, ensure_credentials_queue_sort, NULL);
-
-  task = G_TASK (g_queue_peek_head (self->ensure_credentials_queue));
-  self->ensure_credentials_running = TRUE;
-
-  data = (EnsureData *) g_task_get_task_data (task);
-  account = goa_object_peek_account (data->object);
-
-  id = goa_account_get_id (account);
-  provider_type = goa_account_get_provider_type (account);
-  timestamp = g_get_monotonic_time ();
-  g_debug ("%" G_GINT64_FORMAT ": Handling EnsureCredentials (%s, %s)", timestamp, provider_type, id);
-
-  provider = goa_provider_get_for_provider_type (provider_type);
-  g_assert_nonnull (provider);
-
-  goa_provider_ensure_credentials (provider,
-                                   data->object,
-                                   NULL, /* GCancellable */
-                                   ensure_credentials_queue_collector,
-                                   task);
-
- out:
-  g_clear_object (&provider);
-}
-
-static gboolean
-ensure_credentials_queue_coalesce (GoaDaemon *self, GoaObject *object, GDBusMethodInvocation *invocation)
-{
-  GList *l;
-  GoaAccount *account;
-  const gchar *id;
-  gboolean ret = FALSE;
-  gint priority;
-
-  account = goa_object_peek_account (object);
-  id = goa_account_get_id (account);
-
-  priority = (invocation == NULL) ? G_PRIORITY_LOW : G_PRIORITY_HIGH;
-
-  for (l = self->ensure_credentials_queue->head; l != NULL; l = l->next)
-    {
-      GoaAccount *account_queued;
-      GTask *task = G_TASK (l->data);
-      EnsureData *data;
-      const gchar *id_queued;
-
-      data = g_task_get_task_data (task);
-      account_queued = goa_object_peek_account (data->object);
-      id_queued = goa_account_get_id (account_queued);
-      if (g_strcmp0 (id, id_queued) == 0)
-        {
-          gint priority_queued;
-
-          priority_queued = g_task_get_priority (task);
-          if (priority < priority_queued)
-            g_task_set_priority (task, priority);
-
-          data->invocations = g_list_prepend (data->invocations, invocation);
-
-          ret = TRUE;
-          break;
-        }
-    }
-
-  return ret;
+  ensure_data_unref (data);
 }
 
 static gboolean
@@ -1324,22 +1226,20 @@ on_account_handle_ensure_credentials (GoaAccount            *account,
                                       gpointer               user_data)
 {
   GoaDaemon *self = GOA_DAEMON (user_data);
-  EnsureData *data;
-  GoaObject *object;
   GoaProvider *provider = NULL;
-  GTask *task = NULL;
+  GoaObject *object;
   const gchar *id;
   const gchar *method_name;
   const gchar *provider_type;
-  gint64 timestamp;
 
   id = goa_account_get_id (account);
   provider_type = goa_account_get_provider_type (account);
   method_name = g_dbus_method_invocation_get_method_name (invocation);
-  timestamp = g_get_monotonic_time ();
-  g_debug ("%" G_GINT64_FORMAT ": Received %s (%s, %s)", timestamp, method_name, provider_type, id);
+  g_debug ("Handling %s for account (%s, %s)", method_name, provider_type, id);
 
+  object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (account)));
   provider = goa_provider_get_for_provider_type (provider_type);
+
   if (provider == NULL)
     {
       g_dbus_method_invocation_return_error (invocation,
@@ -1351,30 +1251,14 @@ on_account_handle_ensure_credentials (GoaAccount            *account,
       goto out;
     }
 
-  object = GOA_OBJECT (g_dbus_interface_get_object (G_DBUS_INTERFACE (account)));
-  if (ensure_credentials_queue_coalesce (self, object, invocation))
-    {
-      timestamp = g_get_monotonic_time ();
-      g_debug ("%" G_GINT64_FORMAT ": Coalesced %s (%s, %s)",
-               timestamp,
-               method_name,
-               provider_type,
-               id);
-      goto out;
-    }
-
-  data = ensure_data_new (object, invocation);
-
-  task = g_task_new (self, NULL, NULL, NULL);
-  g_task_set_priority (task, G_PRIORITY_HIGH);
-  g_task_set_task_data (task, data, (GDestroyNotify) ensure_data_unref);
-  g_queue_push_tail (self->ensure_credentials_queue, g_object_ref (task));
-
-  ensure_credentials_queue_check (self);
+  goa_provider_ensure_credentials (provider,
+                                   object,
+                                   NULL, /* GCancellable */
+                                   (GAsyncReadyCallback) ensure_credentials_cb,
+                                   ensure_data_new (self, object, invocation));
 
  out:
   g_clear_object (&provider);
-  g_clear_object (&task);
   return TRUE; /* invocation was handled */
 }
 
@@ -1395,14 +1279,10 @@ goa_daemon_check_credentials (GoaDaemon *self)
   objects = g_dbus_object_manager_get_objects (G_DBUS_OBJECT_MANAGER (self->object_manager));
   for (l = objects; l != NULL; l = l->next)
     {
-      EnsureData *data;
       GoaAccount *account;
       GoaObject *object = GOA_OBJECT (l->data);
       GoaProvider *provider = NULL;
-      GTask *task = NULL;
-      const gchar *id;
       const gchar *provider_type;
-      gint64 timestamp;
 
       account = goa_object_peek_account (object);
       if (account == NULL)
@@ -1413,35 +1293,14 @@ goa_daemon_check_credentials (GoaDaemon *self)
       if (provider == NULL)
         continue;
 
-      id = goa_account_get_id (account);
-      provider_type = goa_account_get_provider_type (account);
-      timestamp = g_get_monotonic_time ();
-      g_debug ("%" G_GINT64_FORMAT ": Calling EnsureCredentials (%s, %s)",
-               timestamp,
-               provider_type,
-               id);
-
-      if (ensure_credentials_queue_coalesce (self, object, NULL))
-        {
-          timestamp = g_get_monotonic_time ();
-          g_debug ("%" G_GINT64_FORMAT ": Coalesced EnsureCredentials (%s, %s)",
-                   timestamp,
-                   provider_type,
-                   id);
-          continue;
-        }
-
-      data = ensure_data_new (object, NULL);
-
-      task = g_task_new (self, NULL, NULL, NULL);
-      g_task_set_priority (task, G_PRIORITY_LOW);
-      g_task_set_task_data (task, data, (GDestroyNotify) ensure_data_unref);
-      g_queue_push_tail (self->ensure_credentials_queue, g_object_ref (task));
+      goa_provider_ensure_credentials (provider,
+                                       object,
+                                       NULL, /* GCancellable */
+                                       (GAsyncReadyCallback) ensure_credentials_cb,
+                                       ensure_data_new (self, object, NULL));
 
       g_clear_object (&provider);
-      g_clear_object (&task);
     }
 
-  ensure_credentials_queue_check (self);
   g_list_free_full (objects, g_object_unref);
 }
