@@ -126,34 +126,6 @@ goa_utils_check_duplicate (GoaClient              *client,
   return ret;
 }
 
-gchar *
-goa_utils_data_input_stream_read_line (GDataInputStream  *stream,
-                                       gsize             *length,
-                                       GCancellable      *cancellable,
-                                       GError           **error)
-{
-  GError *local_error = NULL;
-  gchar *ret = NULL;
-
-  ret = g_data_input_stream_read_line (stream, length, cancellable, &local_error);
-
-  /* Handle g_data_input_stream_read_line returning NULL without
-   * setting an error when there was no content to read.
-   */
-  if (ret == NULL && local_error == NULL)
-    {
-      g_set_error (&local_error,
-                   GOA_ERROR,
-                   GOA_ERROR_FAILED, /* TODO: more specific */
-                   _("Could not parse response"));
-    }
-
-  if (local_error != NULL)
-    g_propagate_error (error, local_error);
-
-  return ret;
-}
-
 void
 goa_utils_set_dialog_title (GoaProvider *provider, GtkDialog *dialog, gboolean add_account)
 {
@@ -380,8 +352,12 @@ goa_utils_keyfile_remove_key (GoaAccount *account, const gchar *key)
 {
   GError *error;
   GKeyFile *key_file;
+  gchar *contents;
   gchar *group;
   gchar *path;
+  gsize length;
+
+  contents = NULL;
 
   path = g_strdup_printf ("%s/goa-1.0/accounts.conf", g_get_user_config_dir ());
   group = g_strdup_printf ("Account %s", goa_account_get_id (account));
@@ -402,11 +378,11 @@ goa_utils_keyfile_remove_key (GoaAccount *account, const gchar *key)
       goto out;
     }
 
-  if (!g_key_file_remove_key (key_file, group, key, NULL))
-    goto out;
+  g_key_file_remove_key (key_file, group, key, NULL);
+  contents = g_key_file_to_data (key_file, &length, NULL);
 
   error = NULL;
-  if (!g_key_file_save_to_file (key_file, path, &error))
+  if (!g_file_set_contents (path, contents, length, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
@@ -415,6 +391,7 @@ goa_utils_keyfile_remove_key (GoaAccount *account, const gchar *key)
     }
 
  out:
+  g_free (contents);
   g_key_file_free (key_file);
   g_free (group);
   g_free (path);
@@ -425,10 +402,12 @@ goa_utils_keyfile_set_boolean (GoaAccount *account, const gchar *key, gboolean v
 {
   GError *error;
   GKeyFile *key_file;
-  gboolean needs_update = FALSE;
-  gboolean old_value;
+  gchar *contents;
   gchar *group;
   gchar *path;
+  gsize length;
+
+  contents = NULL;
 
   path = g_strdup_printf ("%s/goa-1.0/accounts.conf", g_get_user_config_dir ());
   group = g_strdup_printf ("Account %s", goa_account_get_id (account));
@@ -449,31 +428,11 @@ goa_utils_keyfile_set_boolean (GoaAccount *account, const gchar *key, gboolean v
       goto out;
     }
 
-  error = NULL;
-  old_value = g_key_file_get_boolean (key_file, group, key, &error);
-  if (error != NULL)
-    {
-      g_warning ("Error reading key %s from keyfile %s: %s (%s, %d)",
-                 key,
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
-      needs_update = TRUE;
-      g_error_free (error);
-    }
-  else if (old_value != value)
-    {
-      needs_update = TRUE;
-    }
-
-  if (!needs_update)
-    goto out;
-
   g_key_file_set_boolean (key_file, group, key, value);
+  contents = g_key_file_to_data (key_file, &length, NULL);
 
   error = NULL;
-  if (!g_key_file_save_to_file (key_file, path, &error))
+  if (!g_file_set_contents (path, contents, length, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
@@ -482,6 +441,7 @@ goa_utils_keyfile_set_boolean (GoaAccount *account, const gchar *key, gboolean v
     }
 
  out:
+  g_free (contents);
   g_key_file_free (key_file);
   g_free (group);
   g_free (path);
@@ -492,10 +452,12 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
 {
   GError *error;
   GKeyFile *key_file;
-  gboolean needs_update = FALSE;
+  gchar *contents;
   gchar *group;
-  gchar *old_value = NULL;
   gchar *path;
+  gsize length;
+
+  contents = NULL;
 
   path = g_strdup_printf ("%s/goa-1.0/accounts.conf", g_get_user_config_dir ());
   group = g_strdup_printf ("Account %s", goa_account_get_id (account));
@@ -516,31 +478,11 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
       goto out;
     }
 
-  error = NULL;
-  old_value = g_key_file_get_string (key_file, group, key, &error);
-  if (error != NULL)
-    {
-      g_warning ("Error reading key %s from keyfile %s: %s (%s, %d)",
-                 key,
-                 path,
-                 error->message,
-                 g_quark_to_string (error->domain),
-                 error->code);
-      needs_update = TRUE;
-      g_error_free (error);
-    }
-  else if (g_strcmp0 (old_value, value) != 0)
-    {
-      needs_update = TRUE;
-    }
-
-  if (!needs_update)
-    goto out;
-
   g_key_file_set_string (key_file, group, key, value);
+  contents = g_key_file_to_data (key_file, &length, NULL);
 
   error = NULL;
-  if (!g_key_file_save_to_file (key_file, path, &error))
+  if (!g_file_set_contents (path, contents, length, &error))
     {
       g_prefix_error (&error, "Error writing key-value-file %s: ", path);
       g_warning ("%s (%s, %d)", error->message, g_quark_to_string (error->domain), error->code);
@@ -549,9 +491,9 @@ goa_utils_keyfile_set_string (GoaAccount *account, const gchar *key, const gchar
     }
 
  out:
+  g_free (contents);
   g_key_file_free (key_file);
   g_free (group);
-  g_free (old_value);
   g_free (path);
 }
 
@@ -592,6 +534,19 @@ goa_utils_set_error_soup (GError **err, SoupMessage *msg)
 
   switch (msg->status_code)
     {
+    case SOUP_STATUS_CANT_RESOLVE:
+      error_msg = g_strdup (_("Cannot resolve hostname"));
+      break;
+
+    case SOUP_STATUS_CANT_RESOLVE_PROXY:
+      error_msg = g_strdup (_("Cannot resolve proxy hostname"));
+      break;
+
+    case SOUP_STATUS_INTERNAL_SERVER_ERROR:
+    case SOUP_STATUS_NOT_FOUND:
+      error_msg = g_strdup (_("Cannot find WebDAV endpoint"));
+      break;
+
     case SOUP_STATUS_UNAUTHORIZED:
       error_msg = g_strdup (_("Authentication failed"));
       error_code = GOA_ERROR_NOT_AUTHORIZED;
